package com.ruoyi.project.asset.service;

import java.util.List;
import com.ruoyi.project.asset.domain.TLeakagePoints;

/**
 * 漏点清单Service接口
 * 
 * @author ruoyi
 * @date 2024-03-28
 */
public interface ITLeakagePointsService 
{
    /**
     * 查询漏点清单
     * 
     * @param id 漏点清单主键
     * @return 漏点清单
     */
    public TLeakagePoints selectTLeakagePointsById(Long id);

    /**
     * 查询漏点清单列表
     * 
     * @param tLeakagePoints 漏点清单
     * @return 漏点清单集合
     */
    public List<TLeakagePoints> selectTLeakagePointsList(TLeakagePoints tLeakagePoints);

    /**
     * 新增漏点清单
     * 
     * @param tLeakagePoints 漏点清单
     * @return 结果
     */
    public int insertTLeakagePoints(TLeakagePoints tLeakagePoints);

    /**
     * 修改漏点清单
     * 
     * @param tLeakagePoints 漏点清单
     * @return 结果
     */
    public int updateTLeakagePoints(TLeakagePoints tLeakagePoints);

    /**
     * 批量删除漏点清单
     * 
     * @param ids 需要删除的漏点清单主键集合
     * @return 结果
     */
    public int deleteTLeakagePointsByIds(Long[] ids);

    /**
     * 删除漏点清单信息
     * 
     * @param id 漏点清单主键
     * @return 结果
     */
    public int deleteTLeakagePointsById(Long id);
}
